/********************************
  name: Water level sensor module with Arduino Uno, LEDs,
  piezo buzzer,LCD1602 I2C module and SG90 micro servo
  function: Measuring water level; sending
  status about the water level to serial monitor, LEDs and LCD screen;
  activating piezo buzzer and micro servo when the level reach 35-40mm.
  If water level is between:
  10-15mm the green LED will be on till level 20-25mm
  20-25mm the green LED will be off and the blue LED will be on till level 35-40mm
  35-40mm the blue LED will be off and the red LED will be on
  35-40mm the piezo buzzer will be activated too
  and
  switch off when sensor is out of water and dry.
********************************/
//Email:info@acoptex.com
//Website:www.acoptex.com
/********************************/
// include libraries
#include <Wire.h>
#include <LCD.h>
#include <LiquidCrystal_I2C.h>
#include <Servo.h>
/********************************/
int sensorPin = A1;  // select the input pin (must be analog) for the water level sensor module
int GreenPin = 8;      // select the pin for the green LED
int BluePin = 7;      // select the pin for the blue LED
int RedPin = 6;      // select the pin for the red LED
int sensorValue = 0; // variable to store the value coming from the sensor
int speakerPin = A0;  // select the pin for the piezo buzzer
int servoPin = 9;
// note that in Arduino 0016 and earlier, the Servo library supports only servos on only two pins: 9 and 10

Servo Lock;// servo motor definition
LiquidCrystal_I2C lcd(0x3F, 2, 1, 0, 4, 5, 6, 7, 3, POSITIVE);// initialise the LCD
/********************************/
void setup() {
  Serial.begin(9600); // initialize serial communications at 9600 bps
  pinMode(GreenPin, OUTPUT);  // declare the GreenPin as an OUTPUT
  pinMode(BluePin, OUTPUT);  // declare the BluePin as an OUTPUT
  pinMode(RedPin, OUTPUT);  // declare the RedPin as an OUTPUT
  pinMode(speakerPin, OUTPUT); // declare the speakerPin as an OUTPUT
  Lock.attach(servoPin);// servo motor attached to the pin
  pinMode(servoPin, OUTPUT);// declare the servoPin as an OUTPUT
  lcd.begin (16, 2);    // define the LCD as 16 column by 2 rows
  lcd.setBacklightPin(3, POSITIVE);
  lcd.setBacklight(HIGH); // switch on the backlight
  Lock.write(0); // servo initial position
}

void loop() {


  sensorValue = analogRead(sensorPin); // read the value from the sensor
  // send the message about water level to serial monitor

  if (sensorValue <= 0) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl: 0mm");
    lcd.setCursor(0, 1);
    lcd.print("Empty");
    Serial.println("Water level: 0mm - Empty!");
  }
  else if (sensorValue > 0 && sensorValue <= 223) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:0-5mm");
    Serial.println("Water lvl:0-5mm");
    Lock.write(0);
  }
  else if (sensorValue > 223 && sensorValue <= 251) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:5-10mm");
    Serial.println("Water lvl: 5-10mm");
  }
  else if (sensorValue > 251 && sensorValue <= 277) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:10-15mm");
    Serial.println("Water lvl: 10-15mm");
    digitalWrite(GreenPin, HIGH);  // turn the green LED on
    lcd.setCursor(0, 1);
    lcd.print("Water detect");
  }
  else if (sensorValue > 277 && sensorValue <= 294) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:15-20mm");
    digitalWrite(GreenPin, HIGH);
    Serial.println("Water lvl: 15-20mm");
  }
  else if (sensorValue > 294 && sensorValue <= 311) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:20-25mm");
    Serial.println("Water lvl: 20-25mm");
    digitalWrite(GreenPin, LOW);// turn the green LED off
    digitalWrite(BluePin, HIGH);  // turn the blue LED on
    lcd.setCursor(0, 1);
    lcd.print("Water lvl up");
  }
  else if (sensorValue > 311 && sensorValue <= 314) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:25-30mm");
    digitalWrite(BluePin, HIGH);
    Serial.println("Water lvl: 25-30mm");
  }
  else if (sensorValue > 314 && sensorValue <= 323) {
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:30-35mm");
    digitalWrite(BluePin, HIGH);
    Serial.println("Water lvl: 30-35mm");
  }
  else if (sensorValue > 323) {
    digitalWrite(BluePin, LOW); // turn the blue LED off
    digitalWrite(speakerPin, HIGH); // turn the piezo buzzer on
    digitalWrite(RedPin, HIGH);  // turn the red LED on
    lcd.setCursor(0, 0);
    lcd.print("Water lvl:35-40mm");
    lcd.setCursor(0, 1);
    lcd.print("Alarm! Alarm!");
    Serial.println("Water lvl: 35-40mm - Alarm! Alarm! Servo activated");
    Lock.write(90); // turns servo to left 90 degrees
  }
  delay(1000); // delay 1 second
  lcd.clear(); // clear LCD screen
  // take the sensor out of water slowly or fast or if the water level is going down
  // reset the system when sensor out off the water and dry
  digitalWrite(RedPin, LOW);// turn the red LED off
  digitalWrite(speakerPin, LOW);// turn the speakerPin off
  Lock.write(0); // returns servo to initial position
  digitalWrite(BluePin, LOW);  // turn the blue LED off
  digitalWrite(GreenPin, LOW);  // turn the green LED off
}
